@@ -9,7 +9,7 @@ use Perl::Tidy;
 use Data::Dumper;
 use Module::Starter;
 $Data::Dumper::Deparse = 1;
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 our %CLASS;
 our $SUB_INDEX = 1;
 
@@ -252,6 +252,12 @@ sub example {
 	return $self;
 }
 
+sub class_tests {
+	my ($self, @tests) = @_;
+	push @{$CLASS{CURRENT}{CLASS_TESTS}}, @tests;
+	return $self;
+}
+
 sub test {
 	my ($self, @tests) = @_;
 	push @{$CLASS{CURRENT}{SUBS}{CURRENT}{TEST}}, @tests;
@@ -481,7 +487,7 @@ sub _build_pod {
 		subs => join("\n\n", @subs),
 		synopsis => ($definition->{SYNOPSIS}
 			? $definition->{SYNOPSIS}
-			: sprintf("\n\tuse %s;\n\n\tmy \$foo = %s->new();\n\n\t...", $class, $class)
+			: sprintf("Quick summary of what the module does.\n\tuse %s;\n\n\tmy \$foo = %s->new();\n\n\t...", $class, $class)
 		),
 		author => $CLASS{AUTHOR} || "AUTHOR",
 		email => $CLASS{EMAIL} || "EMAIL"
@@ -522,6 +528,16 @@ sub _build_tests {
 	my ($class, $obj_ok) = @_;
 	my $tests = sprintf("our (\$sub, \$globref); BEGIN { use_ok('%s'); \$sub = sub {}; \$globref = \\*globref; }", $class->{NAME});
 
+	if ($class->{CLASS_TESTS}) {
+		my $c = 1;
+		for my $subset (@{$class->{CLASS_TESTS}}) {
+			$tests .= sprintf "subtest 'class_tests$c' => sub { plan tests => %s; %s };",
+				scalar @{$subset},
+				join( '', map{ _build_test($_) } @{ $subset });
+			$c++;
+		}
+	}
+
 	if ($class->{SUBS}->{new}->{TEST}) {
 		$tests .= sprintf "subtest 'new' => sub { plan tests => %s; %s };",
 			scalar @{$class->{SUBS}->{new}->{TEST}},
@@ -539,6 +555,10 @@ sub _build_tests {
 		if $class->{SUBS}->{$sub}->{TEST};
 	}
 
+
+
+
+
 	return $tests;
 }
 
@@ -596,7 +616,6 @@ Version {{version}}
 
 =head1 SYNOPSIS
 
-Quick summary of what the module does.
 {{synopsis}}
 
 {{subs}}
@@ -659,7 +678,7 @@ Module::Generate - Assisting with module generation.
 
 =head1 VERSION
 
-Version 0.23
+Version 0.24
 
 =cut
 
@@ -1051,6 +1070,33 @@ Implement a keyword that can be used accross classes.
 				['is', q|$obj->test|, q|'abc'|]
 			);
 
+=head2 class_tests
+
+Define additional subtests for a class.
+
+	$mg->class_tests([
+		['ok', q|my $obj = do { eval q{
+			package FooBar;
+			use Moo;
+			with 'Keyword::Role';
+			1;
+		}; 1; } && FooBar->new| ],
+		['is', q|$obj->test|, q|undef|],
+		['ok', q|$obj->test('abc')|],
+		['is', q|$obj->test|, q|'abc'|]
+	], [
+		['ok', q|my $obj = do { eval q{
+			package BarFoo;
+			use Moo;
+			with 'Keyword::Role';
+			1;
+		}; 1; } && BarFoo->new| ],
+		['is', q|$obj->test|, q|undef|],
+		['ok', q|$obj->test('abc')|],
+		['is', q|$obj->test|, q|'abc'|]
+	]);
+
+
 =head2 generate
 
 Compile the code.
